#
# spec file for package gamin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum   0
%define vernum  1
%define packnum %{vernum}-%{sonum}
%define famnum  0
Name:           gamin
Version:        0.1.10
Release:        18.1
Summary:        Library providing the FAM File Alteration Monitor API
License:        LGPL-2.1-only
Group:          System/Daemons
URL:            http://www.gnome.org/~veillard/%{name}/
Source0:        https://download.gnome.org/sources/gamin/0.1/gamin-%{version}.tar.bz2
Source2:        %name-rpmlintrc
Source99:       baselibs.conf
Patch0:         gamin-return.patch
Patch1:         gamin-fam_abi_compatibility_FamErrlist.patch
Patch3:         gamin-obsol-glib.diff
# PATCH-FIX-UPSTREAM gamin-0.1.11-double-lock.patch (bgo#669292)
Patch4:         gamin-0.1.11-double-lock.patch
# PATCH-FIX-UPSTREAM 0001-Poll-files-on-nfs4.patch (bgo#693006)
Patch5:         0001-Poll-files-on-nfs4.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)

%description
This C library provides an API and ABI compatible file alteration
monitor mechanism compatible with FAM, but not dependent on a system wide
daemon.

%package doc
Summary:        Documentation for %{name}
Group:          Development/Libraries/C and C++

%description doc
Documentation and help files for %{name}.

%package server
Summary:        Server for the Library providing the FAM File Alteration Monitor API
Group:          System/Daemons
Provides:       fam-server = %{version}-%{release}
Obsoletes:      fam-server < %{version}-%{release}

%description server
This package contains the daemon for %{name}.
It is split off into its own subpackage to void file conflicts when both
%{name} and %{name}-32bit are installed on a multiarch platform.

%prep
%setup -q
%patch0 -p0
%patch1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
%configure --disable-static --enable-tests
make %{?_smp_mflags}

%install
%make_install
rm "%{buildroot}%{_libdir}"/*.la
%fdupes %{buildroot}

# drop files which are build via libgamin spec file
rm %buildroot%{_includedir}/fam.h              \
   %buildroot%{_libdir}/lib%{name}_shared.a    \
   %buildroot%{_libdir}/pkgconfig/gamin.pc     \
   %buildroot%{_libdir}/libgamin-%{vernum}.so* \
   %buildroot%{_libdir}/libfam.so*

%check
# tests are currently broken :/
make tests || echo "**** WARNING TESTSUITE FAILS ****"

%files server
%defattr(-, root, root)
%{_libexecdir}/gam_server

%changelog
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Tue Sep 28 2021 Michael Gorse <mgorse@suse.com>
- Fix source URI.
* Thu Jan  9 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Disable python bindings (python2-only):
  + Drop python-devel BuildRequires.
  + Drop gamin-fix_python_main.patch: no longer needed.
  + No longer build python-gamin sub-package.
* Mon Aug  6 2018 dimstar@opensuse.org
- Add baselibs.conf to the file source list.
* Wed Jul 25 2018 dimstar@opensuse.org
- Replace deprecated macro py_sitedir with python_sitearch.
* Fri Jan 10 2014 adrian@suse.de
- split lib* packages into own spec file to avoid a build cycle
- found a testsuite, run it, but ignore result since it show
  breakages. Should be revisited.
* Tue Sep 24 2013 hrvoje.senjan@gmail.com
- Added 0001-Poll-files-on-nfs4.patch (bgo#693006) and
  gamin-0.1.11-double-lock.patch (bgo#669292)
* Fri Apr 26 2013 coolo@suse.com
- add conflict with libfam0-32bit
* Thu Jan  5 2012 toddrme2178@gmail.com
- Spec file cleanups
- Provide and obsolete libgamin in case of sonum changes
- Have the -devel package provide -devel-static as well since it has .a files
- Changed the baselibs.conf to use the libs per openSUSE policy
- Added duplicate files check
* Wed Jan  4 2012 jengelh@medozas.de
- Use exact EVR for Provide: symbols
* Wed Jan  4 2012 toddrme2178@gmail.com
- Added version for fam-server provides
- Added obsoletes for fam-server
- Added obsoletes for gamin-python
- Switched to original gzipped tar
- Changed source to include upstream source URL to comply with new
  packaging guidelines
* Sun Oct  2 2011 toddrme2178@gmail.com
- Added patch to fix building in factory
- Cleaned up spec file formatting with spec-cleaner
- Added proper license header to spec file
- Split documentation package (fix for RPMLINT warning)
- Add fam-server provides to gamin-server (other gaming packages provide their fam counterpart)
* Thu Sep 22 2011 jengelh@medozas.de
- Implement shlib package (libfam0-gamin)
- Resolve build error due to source disabling deprecated contructs
  that it used
* Tue Sep  1 2009 pascal.bleser@opensuse.org
- add gamin-32bit package through baselibs.conf to fix KDE 32bit compatibility libs (thanks to Martin Vogt for reporting), which requires splitting %%{_libexecdir}/gam_server into its own subpackage (gamin-server) to avoid file conflicts when both gamin and gamin-32bit are installed -- note that gamin and gamin-32bit both require the package gamin-server, so nothing needs to be done on the user end
* Sat Jul 25 2009 pascal.bleser@opensuse.org
- add patch to be completely ABI compatible with fam, in order to avoid warnings and crashes caused by "Symbol `FamErrlist' has different size in shared object, consider re-linking"; references:
  * http://lists.opensuse.org/yast-devel/2009-02/msg00000.html
  * http://www.nabble.com/Bug-437307:-lighttpd-fails-to-restart-after-update-td12107383.html
* Thu Mar 12 2009 detlef@links2linux.de
- add return.patch
* Sat Jan  3 2009 detlef@links2linux.de
- new upstream version <0.1.10>
* Wed Jul 16 2008 detlef@links2linux.de
- initial build for PackMan
* Thu Oct 27 2005 veillard@redhat.com
- hopefully fixes gam_server crashes
- some portability fixes
- removed a minor leak
* Thu Sep  8 2005 veillard@redhat.com
- revamp of the inotify back-end
- memory leak fix
- various fixes and cleanups
* Tue Aug  9 2005 veillard@redhat.com
- Improvement of configuration, system wide configuration files and
  per filesystem type default
- Rewrite of the inotify back-end, reduce resources usage, tuning in
  case of busy resources
- Documentation updates
- Changes to compile inotify back-end on various architectures
- Debugging output improvements
* Tue Aug  2 2005 veillard@redhat.com
- Fix to compile on older gcc versions
- Inotify back-end changes and optimizations
- Debug ouput cleanup, pid and process name reports
- Dropped kernel monitor bugfix
- Removed the old glist copy used for debugging
- Maintain mounted filesystems knowledge, and per fstype preferences
* Wed Jul 13 2005 veillard@redhat.com
- inotify back end patches, ready for the new inotify support in kernel
- lot of server code cleanup patches
- fixed an authentication problem
* Fri Jun 10 2005 veillard@redhat.com
- gamin_data_conn_event fix
- crash from bug gnome #303932
- Inotify and mounted media #171201
- mounted media did not show up on Desktop #159748
- write may not be atomic
- Monitoring a directory when it is a file
- Portability to Hurd/Mach and various code cleanups
- Added support for ~ as user home alias in .gaminrc
* Thu May 12 2005 veillard@redhat.com
- Close inherited file descriptors on exec of gam_server
- Cancelling a monitor send back a FAMAcknowledge
- Fixed for big files > 2GB
- Bug when monitoring a non existing directory
- Make client side thread safe
- Unreadable directory fixes
- Better flow control handling
- Updated to latest inotify version: 0.23-6
* Tue Mar 15 2005 veillard@redhat.com
- Fix an include problem showing up with gcc4</li>
- Fix the crash on failed tree assert bug #150471 based on patch from Dean Brettle
- removed an incompatibility with SGI FAM #149822
* Tue Mar  1 2005 veillard@redhat.com
- Fix a configure problem reported by Martin Schlemmer
- Fix the /media/* and /mnt/* mount blocking problems from 0.0.24 e.g. #142637
- Fix the monitoring of directory using poll and not kernel
* Fri Feb 18 2005 veillard@redhat.com
- more documentation
- lot of serious bug fixes including Gnome Desktop refresh bug
- extending the framework for more debug (configure --enable-debug-api)
- extending the python bindings for watching the same resource multiple times
  and adding debug framework support
- growing the regression tests a lot based on python bindings
- inotify-0.19 patch from John McCutchan
- renamed python private module to _gamin to follow Python PEP 8
* Tue Feb  8 2005 veillard@redhat.com
- memory corruption fix from Mark on the client side
- extending the protocol and API to allow skipping Exists and EndExists
  events to avoid deadlock on reconnect or when they are not used.
* Mon Jan 31 2005 veillard@redhat.com
- bit of python bindings improvements, added test
- fixed 3 bugs
* Wed Jan 26 2005 veillard@redhat.com
- Added Python support
- Updated for inotify-0.18
* Thu Jan  6 2005 veillard@redhat.com
- Frederic Crozat seems to have found the GList corruption which may fix
- Frederic Crozat also fixed poll only mode
* Fri Dec  3 2004 veillard@redhat.com
- still chasing the loop bug, made another pass at checking GList,
  added own copy with memory poisonning of GList implementation.
- fixed a compile issue when compiling without debug
* Fri Nov 26 2004 veillard@redhat.com
- still chasing the loop bug, checked and cleaned up all GList use
- patch from markmc to minimize load on busy apps
* Wed Oct 20 2004 veillard@redhat.com
- chasing #132354, lot of debugging, checking and testing and a bit
  of refactoring
* Sat Oct 16 2004 veillard@redhat.com
- workaround to detect loops and avoid the nasty effects, see RedHat bug #132354
* Sun Oct  3 2004 veillard@redhat.com
- Found and fixed the annoying bug where update were not received
  should fix bugs ##132429, #133665 and #134413
- new mechanism to debug on-the-fly by sending SIGUSR2 to client or server
- Added documentation about internals
* Fri Oct  1 2004 veillard@redhat.com
- applied portability fixes
- hardened the code while chasing a segfault
* Thu Sep 30 2004 veillard@redhat.com
- potential fix for a hard to reproduce looping problem.
* Mon Sep 27 2004 veillard@redhat.com
- update to the latest version of inotify
- inotify support compiled in by default
- fix ABI FAM compatibility problems #133162
* Tue Sep 21 2004 veillard@redhat.com
- more documentation
- Added support for a configuration file $HOME/.gaminrc
- fixes FAM compatibility issues with FAMErrno and FamErrlist #132944
* Wed Sep  1 2004 veillard@redhat.com
- fix crash with konqueror #130967
- exclude kernel (dnotify) monitoring for /mnt//* /media//*
* Thu Aug 26 2004 veillard@redhat.com
- Fixes crashes of the gam_server
- try to correct the kernel/poll switching mode
* Tue Aug 24 2004 veillard@redhat.com
- add support for both polling and dnotify simultaneously
- fixes monitoring of initially missing files
- load control on very busy resources #124361, desactivating
  dnotify and falling back to polling for CPU drain
* Thu Aug 19 2004 veillard@redhat.com
- fixes simple file monitoring should close RH #129974
- relocate gam_server in $(libexec)
* Thu Aug  5 2004 veillard@redhat.com
- Fix a crash when the client binary forks the gam_server and an
  atexit handler is run.
* Wed Aug  4 2004 veillard@redhat.com
- should fix KDE build problems
